<?php

namespace Concrete\Package\OunziwOsm\Block\Map;

use Concrete\Core\Block\BlockController;
use Core;
use Asset;
use AssetList;
use Concrete\Core\View\View;
class Controller extends BlockController
{

    protected $btInterfaceWidth = 400;
    protected $btInterfaceHeight = 600;
    protected $btTable = 'btOunziwmap';

    public function getBlockTypeDescription()
    {
        return t("Dsiplays a map using Open Street Map.");
    }

    public function getBlockTypeName()
    {
        return t("OSM Free Map");
    }

    public function view()
    {
        $this->set('unique_identifier', Core::make('helper/validation/identifier')->getString(18));
    }

    public function on_start() {
        $v = View::getInstance();
        $v->requireAsset('css', 'leaflet');
        $v->requireAsset('javascript', 'jquery');
        $v->requireAsset('javascript', 'leaflet');
    }
    public function registerViewAssets($outputContent = '')
    {
        $this->requireAsset('javascript', 'jquery');
        $al = AssetList::getInstance();
        $al->register(
            'javascript', 'leaflet', 'js/leaflet.min.js', array('position'=>Asset::ASSET_POSITION_HEADER), 'ounziw_osm'
        );
        $al->register(
            'css', 'leaflet', 'css/leaflet.css', array(), 'ounziw_osm'
        );
    }
    public function validate($args)
    {
        $error = Core::make('helper/validation/error');

        if ($args['latitude'] === '' || $args['longtitude'] === '') {
            $error->add(t('You must select a valid location.'));
        }

        if (!is_numeric($args['zoom'])) {
            $error->add(t('Please enter a zoom number from 0 to 21.'));
        }

        if ($args['marker'] && ($args['markerlatitude'] === '' || $args['markerlongitude'] === '')) {
            $error->add(t('You must select a valid location for the marker.'));
        }

        if ($error->has()) {
            return $error;
        }
    }

    public function save($data)
    {
        $args['width'] = isset($data['width']) ? trim($data['width']) : '';
        $args['height'] = isset($data['height']) ? trim($data['height']) : '';
        $args['zoom'] = (intval($data['zoom']) >= 0 && intval($data['zoom']) <= 21) ? intval($data['zoom']) : 14;
        $args['latitude'] = is_numeric($data['latitude']) ? $data['latitude'] : 0;
        $args['longitude'] = is_numeric($data['longitude']) ? $data['longitude'] : 0;
        $args['marker'] = $data['marker'] ? 1 : 0;
        $args['markerlatitude'] = is_numeric($data['markerlatitude']) ? $data['markerlatitude'] : 0;
        $args['markerlongitude'] = is_numeric($data['markerlongitude']) ? $data['markerlongitude'] : 0;
        $args['message'] = isset($data['message']) ? trim($data['message']) : '';
        parent::save($args);

    }
}
